==> clutternomore-1.1.3%2B1.21.1-fabric-sources.jar: dev/tazer/clutternomore/common/registry/CBlocks.java <==
package dev.tazer.clutternomore.common.registry;

import dev.tazer.clutternomore.ClutterNoMore;
import java.util.function.Supplier;
import net.minecraft.class_1747;
import net.minecraft.class_1792;
import net.minecraft.class_2248;
import net.minecraft.class_5321;
import net.minecraft.class_7924;

public class CBlocks {
//    public static final DeferredRegister.Blocks BLOCKS = DeferredRegister.createBlocks(ClutterNoMore.MODID);

//    public static final Supplier<VerticalSlabBlock> STONE_TILE_VERTICAL_SLAB = register(
//            "stone_tile_vertical_slab",
//            () -> new VerticalSlabBlock(BlockBehaviour.Properties.ofFullCopy(Blocks.STONE_SLAB))
//    );
//
//    public static final Supplier<VerticalSlabBlock> ACACIA_VERTICAL_SLAB = register(
//            "acacia_vertical_slab",
//            () -> new VerticalSlabBlock(BlockBehaviour.Properties.ofFullCopy(Blocks.ACACIA_SLAB))
//    );

    public static <T extends class_2248> Supplier<T> register(String name, Supplier<T> block) {
        Supplier<T> toReturn = CommonRegistry.registerBlock(name, block);
        registerBlockItem(name, toReturn);
        return toReturn;
    }

    public static <T extends class_2248> Supplier<T> registerBlock(String name, Supplier<T> block) {
        return CommonRegistry.registerBlock(name, block);
    }

    public static class_5321<class_2248> registryKey(String string) {
        return class_5321.method_29179(class_7924.field_41254, ClutterNoMore.location(string));
    }

    public static void registerBlockItem(String name, Supplier<? extends class_2248> block) {
        CItems.register(name, () -> new class_1747(block.get(), new class_1792.class_1793()
                //? if >1.21.2 {
                /*.setId(ResourceKey.create(Registries.ITEM, ClutterNoMore.location(name)
                )).useBlockDescriptionPrefix()
                *///?}
                ));
    }

    public static void register() {

    }
}

==> clutternomore-1.1.6%2B1.21.5-fabric-sources.jar: dev/tazer/clutternomore/common/registry/CBlocks.java <==
package dev.tazer.clutternomore.common.registry;

import dev.tazer.clutternomore.ClutterNoMore;
import java.util.function.Supplier;
import net.minecraft.class_1747;
import net.minecraft.class_1792;
import net.minecraft.class_2248;
import net.minecraft.class_5321;
import net.minecraft.class_7924;

public class CBlocks {
//    public static final DeferredRegister.Blocks BLOCKS = DeferredRegister.createBlocks(ClutterNoMore.MODID);

//    public static final Supplier<VerticalSlabBlock> STONE_TILE_VERTICAL_SLAB = register(
//            "stone_tile_vertical_slab",
//            () -> new VerticalSlabBlock(BlockBehaviour.Properties.ofFullCopy(Blocks.STONE_SLAB))
//    );
//
//    public static final Supplier<VerticalSlabBlock> ACACIA_VERTICAL_SLAB = register(
//            "acacia_vertical_slab",
//            () -> new VerticalSlabBlock(BlockBehaviour.Properties.ofFullCopy(Blocks.ACACIA_SLAB))
//    );

    public static <T extends class_2248> Supplier<T> register(String name, Supplier<T> block) {
        Supplier<T> toReturn = CommonRegistry.registerBlock(name, block);
        registerBlockItem(name, toReturn);
        return toReturn;
    }

    public static <T extends class_2248> Supplier<T> registerBlock(String name, Supplier<T> block) {
        return CommonRegistry.registerBlock(name, block);
    }

    public static class_5321<class_2248> registryKey(String string) {
        return class_5321.method_29179(class_7924.field_41254, ClutterNoMore.location(string));
    }

    public static void registerBlockItem(String name, Supplier<? extends class_2248> block) {
        CItems.register(name, () -> new class_1747(block.get(), new class_1792.class_1793()
                //? if >1.21.2 {
                .method_63686(class_5321.method_29179(class_7924.field_41197, ClutterNoMore.location(name)
                )).method_63685()
                //?}
                ));
    }

    public static void register() {

    }
}
